use std::fs;

use image::imageops;
use image::GrayAlphaImage;

use proj::Proj;

const PROJ_WGS84_DE1200: &'static str = "+proj=stere +lat_0=90 +lat_ts=60 +lon_0=10 +a=6378137 +b=6356752.3142451802 +no_defs +x_0=543196.83521776402 +y_0=3622588.8619310018";

enum State {
    Header,
    Lsb,
    Msb(u8),
}

fn main() {
    let mut state = State::Header;
    let mut data = Vec::with_capacity(1100 * 1200 * 2);

    for b in fs::read("input").unwrap() {
        match state {
            State::Header if b == 3 => {
                state = State::Lsb;
            }
            State::Header => (),
            State::Lsb => {
                state = State::Msb(b);
            }
            State::Msb(lsb) => {
                let v = u16::from_le_bytes([lsb, b]);

                if v == 0x29c4 {
                    data.push(0);
                    data.push(255);
                } else {
                    data.push(if v > 0 { 255 } else { 127 });
                    data.push(255);
                }

                state = State::Lsb;
            }
        };
    }

    let mut img = GrayAlphaImage::from_raw(1100, 1200, data).unwrap();
    imageops::flip_vertical_in_place(&mut img);
    img.save("rv.png").unwrap();

    let wgs84_to_de1200 = Proj::new(PROJ_WGS84_DE1200).unwrap();
    println!(
        "{:#?}",
        wgs84_to_de1200
            .project(
                (1.463301510_f64.to_radians(), 55.86208711_f64.to_radians()),
                false
            )
            .unwrap()
    );
}
